@@ -1,9 +1,9 @@
 package ColorTheme;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-08'; # DATE
+our $DATE = '2020-06-09'; # DATE
 our $DIST = 'ColorTheme'; # DIST
-our $VERSION = '2.0.1'; # VERSION
+our $VERSION = '2.1.0'; # VERSION
 
 1;
 # ABSTRACT: Color themes
@@ -24,12 +24,17 @@ ColorTheme - Color themes
 
 =head1 VERSION
 
-This document describes version 2.0.1 of ColorTheme (from Perl distribution ColorTheme), released on 2020-06-08.
+This document describes version 2.1.0 of ColorTheme (from Perl distribution ColorTheme), released on 2020-06-09.
 
 =head1 DESCRIPTION
 
 This document specifies a way to create and use color themes.
 
+=head1 SPECIFICATION STATUS
+
+The series 2.x version is still unstable. API might still change between
+releases.
+
 =head1 GLOSSARY
 
 =head2 color theme
@@ -116,6 +121,26 @@ Usage:
 Constructor. Known arguments will depend on the particular theme class and must
 be specified in the color theme structure under the C<args> key.
 
+=item * get_struct
+
+Usage:
+
+ my $theme_struct = $theme_class->get_struct;
+
+Provide a method way of getting the L</color theme structure>. A client can also
+access the C<%THEME> package variable directly.
+
+=item * get_args
+
+Usage:
+
+ my $theme_class_args = $theme_class->get_args;
+
+Provide a method way of getting the arguments to the constructor. The official
+implementation L<ColorThemeBase::Constructor> stores this in the 'args' key of
+the hash object, but the proper way to access the arguments should be via this
+method.
+
 =item * list_items
 
 Usage:
@@ -126,15 +151,13 @@ Usage:
 Must return list of item names provided by theq theme. Each item has a color
 associated with it and the color can be retrieved using L</get_color>.
 
-=item * get_color
+=item * get_item_color
 
 Usage:
 
- my $color = $theme_class->get_color($item_name [ , \%args ]);
+ my $color = $theme_class->get_item_color($item_name [ , \%args ]);
 
-Get color for an item. The color can be a single RGB value, e.g. C<ffcc00> or a
-DefHash e.g. C<< {fg=>'ffcc00', bg=>'333333', summary=>'...'} >> (all keys
-optional).
+Get color for an item. See L<Item color>.
 
 =back
 
@@ -165,28 +188,42 @@ of the important or relevant properties: C<req>, C<schema>, C<default>.
 =item * dynamic
 
 Boolean, optional. Must be set to true if the theme class is dynamic, i.e. the
-L</colors> property does not contain all (or even any) of the items of the
-theme. Client must call L</list_items> to list all the items in the theme.
+L</items> property does not contain all (or even any) of the items of the theme.
+Client must call L</list_items> to list all the items in the theme.
 
-=item * colors
+=item * items
 
-Required. Hash of item names as keys and colors as values.
-
-Color can be a single RGB value, e.g. C<ffcc00> or a DefHash e.g. C<<
-{fg=>'ffcc00', bg=>'cc0000', ansi_fg=>..., ansi_bg=>..., summary=>..., ...} >>
-(all keys optional) or a coderef. The coderef will be supplied arguments of
-L</get_color> and is expected to retruen an RGB string or a DefHash.
-
-A DefHash color containing multiple color codes is used to support specifying
-foreground/background values or ANSI color codes that are not representable by
-RGB, among other things. You can also put summary and additional information in
-the DefHash.
-
-Allowing coderef as color allows for flexibility, e.g. for doing gradation
-border color, random color, etc.
+Required. Hash of item names as keys and item colors as values. See L</Item
+color>.
 
 =back
 
+=head2 Item color
+
+The color of an item can be one of three things.
+
+First, the simplest, a single RGB value in the form of 6-hexdigit string, e.g.
+C<ffcc00>.
+
+Second, a DefHash called "item colors hash" containing one or more of these
+properties: C<fg> (foreground RGB color), C<bg> (background RGB color),
+C<ansi_fg> (foreground ANSI escape sequence string), C<ansi_bg> (background ANSI
+escape sequence string). It can also contain additional information like
+C<summary> (a summary describing the item), C<description>, C<tags>, and so on.
+Properties like C<ansi_fg> and C<ansi_bg> are used to support specifying things
+that are not representable by RGB, e.g. reverse or bold.
+
+Third, a coderef which if called is expected to return one of the two formerly
+mentioned value (RGB string or the "item colors hash"). A coderef cannot return
+another coderef. Coderef will be called with arguments C<< ($self, $name,
+\%args) >> where C<$self> is the color theme class (from which you can access
+the color theme structure as well as arguments to the constructor), C<$name> is
+the item name requested, and C<\%args> is hashref to additional, per-item
+arguments.
+
+Allowing coderef as color allows for flexibility, e.g. for doing gradation
+border color, random color, context-sensitive color, etc.
+
 =head1 HISTORY
 
 L<Color::Theme> is an older specification, superseded by this document.
